"""Terraform project analysis and visualization toolkit."""

__version__ = "0.4.41"
__author__ = "Ivan Kovtun"
__email__ = "kovtun.ivan@proton.me"
__description__ = "Advanced Terraform Intelligence & Analysis Suite"
__url__ = "https://github.com/ivasik-k7/tfkit"
__license__ = "MIT"

from tfkit.cli import cli

__all__ = ["cli", "__version__"]
